@@ -3,9 +3,7 @@ import shutil
 from abc import ABC, abstractmethod
 from pathlib import Path
 import tempfile
-import importlib
 from typing import (
-    Callable,
     Generic,
     List,
     Any,
@@ -85,7 +83,7 @@ class HyperState(ABC, Generic[C, S]):
         try:
             self.config, self.schedules = _typed_load(
                 config_clz,
-                config_path,
+                file=config_path,
                 overrides=overrides or [],
                 allow_missing_version=state_path is not None,
                 ignore_extra_fields=ignore_extra_fields,
@@ -96,7 +94,12 @@ class HyperState(ABC, Generic[C, S]):
             self.state = self.initial_state()
         else:
             try:
-                self.state = _typed_load(state_clz, state_path, config=self.config, ignore_extra_fields=ignore_extra_fields)[0]
+                self.state = _typed_load(
+                    state_clz,
+                    file=state_path,
+                    config=self.config,
+                    ignore_extra_fields=ignore_extra_fields,
+                )[0]
             except Exception as e:
                 raise RuntimeError(
                     f"Failed to load state from {state_path}: {e}"
@@ -150,7 +153,7 @@ def _apply_schedules(state: Any, config: Any, schedules: Dict[str, Any]) -> None
 
 def _typed_dump(
     obj: Any,
-    path: Optional[Path] = None,
+    file: Union[Path, None] = None,
     schedules: Optional[Dict[str, Any]] = None,
     elide_defaults: bool = False,
 ) -> str:
@@ -161,25 +164,31 @@ def _typed_dump(
         serializers.append(ScheduleSerializer(schedules))
     if elide_defaults:
         serializers.append(ElideDefaults())
-    result = serde.dump(obj, path, serializers=serializers)
-    if path is not None:
+    if file is None:
+        return serde.dumps(obj, serializers=serializers)
+    else:
+        result = serde.dump(obj, file, serializers=serializers)
         for blobpath, blob in lazy_serializer.blobs.items():
-            with open(path.parent / blobpath, "wb") as f:
+            with open(file.parent / blobpath, "wb") as f:
                 f.write(blob)
-    return result
+        return result
 
 
-def dump(obj: Any, path: Optional[Path] = None, elide_defaults: bool = False) -> str:
-    return _typed_dump(obj, path, elide_defaults=elide_defaults)
+def dump(obj: Any, file: Union[Path, str], elide_defaults: bool = False) -> None:
+    if isinstance(file, str):
+        file = Path(file)
+    _typed_dump(obj, file, elide_defaults=elide_defaults)
 
 
 def dumps(obj: Any, elide_defaults: bool = False) -> str:
-    return dump(obj, elide_defaults=elide_defaults)
+    return _typed_dump(obj, elide_defaults=elide_defaults)
 
 
 def _typed_load(
     clz: Type[T],
-    source: Union[str, Path, None],
+    *,
+    file: Optional[Path] = None,
+    data: Optional[str] = None,
     overrides: Optional[List[str]] = None,
     config: Optional[Any] = None,
     allow_missing_version: bool = False,
@@ -193,12 +202,23 @@ def _typed_load(
     deserializers.append(schedules)
     deserializers.append(VersionedDeserializer(allow_missing_version))
     lazy = None
-    if isinstance(source, Path):
-        lazy = LazyDeserializer(config, source.absolute().parent)
+    assert file is None or data is None, "cannot specify both file and source"
+    if file is not None:
+        lazy = LazyDeserializer(config, file.absolute().parent)
         deserializers.append(lazy)
-    elif source is None:
-        source = "{}"
-    value = serde.load(clz, source, deserializers=deserializers, ignore_extra_fields=ignore_extra_fields)
+        value = serde.load(
+            clz,
+            file,
+            deserializers=deserializers,
+            ignore_extra_fields=ignore_extra_fields,
+        )
+    else:
+        value = serde.loads(
+            clz,
+            data or "{}",
+            deserializers=deserializers,
+            ignore_extra_fields=ignore_extra_fields,
+        )
     if lazy is not None and len(lazy.lazy_fields) > 0:
         value._unloaded_lazy_fields = lazy.lazy_fields  # type: ignore
     return value, schedules.schedules
@@ -210,17 +230,19 @@ def loads(
     overrides: Optional[List[str]] = None,
     ignore_extra_fields: bool = False,
 ) -> T:
-    return _typed_load(clz, value, overrides, ignore_extra_fields=ignore_extra_fields)[0]
+    return _typed_load(
+        clz, data=value, overrides=overrides, ignore_extra_fields=ignore_extra_fields
+    )[0]
 
 
 def load(
     clz: Type[T],
-    path: Union[str, Path, None],
+    file: Union[str, Path, None],
     overrides: Optional[List[str]] = None,
 ) -> T:
-    if isinstance(path, str):
-        path = Path(path)
-    return _typed_load(clz, path, overrides)[0]
+    if isinstance(file, str):
+        file = Path(file)
+    return _typed_load(clz, file=file, overrides=overrides)[0]
 
 
 def find_latest_checkpoint(dir: Path) -> Optional[Path]:
